Isn't the normal acceleration always towards the center? | Physics Forums
Description: 1. The problem statement, all variables and given/known data 2. Relevant equations See attachment 3. The attempt at a solution I solved the problem (on the same page as problem, written in pencil) but the direction of the acceleration that I calculated is different, I dont...

- Forums
  - Search Forums
  - Recent Posts
  - Unanswered Threads
- Videos
  - Physics
  - Math
  - Other Science
  - Interviews
  - Pop Science
  - Experiments
  - Entertainment
- Members
  - Notable Members
  - Current Visitors
  - Recent Activity
  - New Profile Posts
- Insights
- Search

### Log in or Sign up

1. Limited time only! Sign up for a free 30min personal tutor trial with Chegg Tutors
   Dismiss Notice

Dismiss Notice
Join Physics Forums Today!
The friendliest, high quality science and math community on the planet! Everyone who loves science is here!

# Homework Help: Isn't the normal acceleration always towards the center?

1. Feb 20, 2007 #1

   ### cipotilla

   ###

   > 1. The problem statement, all variables and given/known data
   > 2. Relevant equations
   > See attachment
   > 3. The attempt at a solution
   > I solved the problem (on the same page as problem, written in pencil) but the direction of the acceleration that I calculated is different, I dont understand why my answer is wrong if the normal acceleration always towards the center and the tangent acceleration is suppossed to be clockwise.

   #### Attached Files:

   - ###### Direction of acceleration.pdf

     File size:
       34.8 KB
     Views:
       188
   cipotilla, Feb 20, 2007
2. Phys.org - latest science and technology news stories on Phys.org
   - • Oleo Sponge successful in real-world conditions off California coast
   - • Close-ups of grain boundaries reveal how sulfur impurities make nickel brittle
   - • Solutions to water challenges reside at the interface
3. Feb 20, 2007 #2

   ### Doc Al

   ### Staff: Mentor

   > Yes, the radial acceleration is towards the center. But I don't see why you think your solution is different from the book's. Seems to me you are just measuring your angle from a different reference direction--they measure from the horizontal, you from the vertical.

   Doc Al, Feb 20, 2007
4. Feb 21, 2007 #3

   ### cipotilla

   ###

   > Doc Al said: ↑

   > > Yes, the radial acceleration is towards the center. But I don't see why you think your solution is different from the book's. Seems to me you are just measuring your angle from a different reference direction--they measure from the horizontal, you from the vertical.

   > I think I measured from the horizontal, thats why I think my answer is different from the books, see diagram. Thanks!

   #### Attached Files:

   - ###### Acceleration direction.pdf

     File size:
       13.4 KB
     Views:
       44
   cipotilla, Feb 21, 2007
5. Feb 21, 2007 #4

   ### Doc Al

   ### Staff: Mentor

   > Looks to me like your diagram is sideways, compared to the original diagram given with the problem. What you call "horizontal" appears as vertical in the original diagram.

   Doc Al, Feb 21, 2007
6. Feb 21, 2007 #5

   ### cipotilla

   ###

   > You are absolutely right, drew my acceleration vectors on the right side of the pulley, where there is no conveyor belt, thats why I got confused. Ok, thanks you.

   cipotilla, Feb 21, 2007

Show Ignored Content
Share this great discussion with others via Reddit, Google+, Twitter, or Facebook

- Log in with Facebook
- Log in with Twitter

Your name or email address:

Do you already have an account?
  - No, create an account now.
  - Yes, my password is:
  - Forgot your password?

  Stay logged in